@@ -16,7 +16,7 @@ $client->get('/test', sub {
     my ($resp, $err) = @_;
 
     if ($err) {
-        print "Error: $err\n";
+        print "Error: $err->{message}\n";
     } else {
         print "Response:\n";
         print Dumper($resp);
