@@ -19,7 +19,7 @@ $client->put('/test', 'hello from perl', sub {
     my ($resp, $err) = @_;
 
     if ($err) {
-        print "Put error: $err\n";
+        print "Put error: $err->{message}\n";
         EV::break;
         return;
     }
@@ -34,7 +34,7 @@ $client->put('/test', 'hello from perl', sub {
         my ($resp, $err) = @_;
 
         if ($err) {
-            print "Get error: $err\n";
+            print "Get error: $err->{message}\n";
         } else {
             print "Get succeeded!\n";
             print "Response: ", Dumper($resp);
