@@ -20,7 +20,7 @@ $client->watch('/watchtest', sub {
     my ($resp, $err) = @_;
 
     if ($err) {
-        print "Watch error: $err\n";
+        print "Watch error: $err->{message}\n";
         EV::break;
         return;
     }
