@@ -449,6 +449,7 @@ void init_method_slices(void);
 
 /*
  * Helper macro for simple string error callback.
+ * Returns a structured error hashref consistent with CALL_ERROR_CALLBACK.
  *
  * Usage:
  *   CALL_SIMPLE_ERROR_CALLBACK(callback, "Error message");
@@ -458,7 +459,8 @@ void init_method_slices(void);
         dSP; \
         ENTER; SAVETMPS; PUSHMARK(SP); EXTEND(SP, 2); \
         PUSHs(&PL_sv_undef); \
-        PUSHs(sv_2mortal(newSVpv(message, 0))); \
+        PUSHs(sv_2mortal(create_error_hv(aTHX_ GRPC_STATUS_INTERNAL, \
+            message, strlen(message), "internal"))); \
         PUTBACK; call_sv(callback, G_DISCARD); FREETMPS; LEAVE; \
     } while (0)
 
