@@ -2,7 +2,7 @@ package EV::Etcd;
 use strict;
 use warnings;
 
-our $VERSION = '0.01_01';
+our $VERSION = '0.02';
 
 require XSLoader;
 XSLoader::load('EV::Etcd', $VERSION);
@@ -58,14 +58,14 @@ EV::Etcd - Async etcd v3 client using native gRPC and EV/libev
     # Async put
     $client->put('/my/key', 'value', sub {
         my ($resp, $err) = @_;
-        die $err if $err;
+        die $err->{message} if $err;
         say "Put succeeded, revision: $resp->{header}{revision}";
     });
 
     # Async get
     $client->get('/my/key', sub {
         my ($resp, $err) = @_;
-        die $err if $err;
+        die $err->{message} if $err;
         say "Value: $resp->{kvs}[0]{value}";
     });
 
@@ -571,14 +571,14 @@ Example:
     # First, create a lease for the lock
     $client->lease_grant(30, sub {
         my ($lease_resp, $err) = @_;
-        die $err if $err;
+        die $err->{message} if $err;
 
         my $lease_id = $lease_resp->{id};
 
         # Now acquire the lock
         $client->lock("my-resource", $lease_id, sub {
             my ($lock_resp, $err) = @_;
-            die $err if $err;
+            die $err->{message} if $err;
 
             my $lock_key = $lock_resp->{key};
             print "Lock acquired with key: $lock_key\n";
@@ -698,11 +698,11 @@ Example:
     # First create root user
     $client->user_add('root', 'rootpassword', sub {
         my ($resp, $err) = @_;
-        die $err if $err;
+        die $err->{message} if $err;
 
         $client->user_grant_role('root', 'root', sub {
             my ($resp, $err) = @_;
-            die $err if $err;
+            die $err->{message} if $err;
 
             # Now safe to enable auth
             $client->auth_enable(sub {
